@@ -27,6 +27,7 @@
 #include <assert.h>
 #include <signal.h>
 #include <string.h>
+#include <unistd.h>
 
 #include <verto.h>
 
@@ -88,6 +89,8 @@ main(int argc, char **argv)
             break;
     }
 
+    verto_cleanup();
+
     return retval;
 }
 
